pub enum TransactionKernelError {
Show 28 variants
AccountDeltaAddAssetFailed(AccountDeltaError),
AccountDeltaRemoveAssetFailed(AccountDeltaError),
FailedToAddAssetToNote(NoteError),
InvalidNoteStorage {
expected: Word,
actual: Word,
},
MissingAuthenticator,
SignatureGenerationFailed(AuthenticationError),
TransactionSummaryCommitmentMismatch(Box<dyn Error + Send + Sync + 'static>),
TransactionSummaryConstructionFailed(Box<dyn Error + Send + Sync + 'static>),
MalformedAssetInEventHandler {
handler: &'static str,
source: AssetError,
},
MalformedNoteStorage(NoteError),
MalformedNoteScript {
data: Vec<Felt>,
source: DeserializationError,
},
MalformedRecipientData(Vec<Felt>),
MissingNote(usize),
PublicNoteMissingDetails(NoteMetadata, Word),
NoteAttachmentNoneIsNotEmpty,
NoteAttachmentArrayMismatch {
actual: Word,
provided: Word,
},
TooFewElementsForNoteStorage {
specified: u64,
actual: u64,
},
UnknownAccountProcedure(Word),
UnknownCodeCommitment(Word),
AccountStorageSlotsNumMissing(u32),
NonceCanOnlyIncrementOnce,
FailedToConvertFeeAsset(AssetError),
GetForeignAccountInputs {
foreign_account_id: AccountId,
ref_block: BlockNumber,
source: DataStoreError,
},
GetVaultAssetWitness {
vault_root: Word,
asset_key: AssetVaultKey,
source: DataStoreError,
},
GetStorageMapWitness {
map_root: Word,
map_key: StorageMapKey,
source: DataStoreError,
},
InsufficientFee {
account_balance: u64,
tx_fee: u64,
},
Unauthorized(Box<TransactionSummary>),
Other {
message: Box<str>,
source: Option<Box<dyn Error + Send + Sync + 'static>>,
},
}Variants
AccountDeltaAddAssetFailed(AccountDeltaError)
AccountDeltaRemoveAssetFailed(AccountDeltaError)
FailedToAddAssetToNote(NoteError)
InvalidNoteStorage
MissingAuthenticator
SignatureGenerationFailed(AuthenticationError)
TransactionSummaryCommitmentMismatch(Box<dyn Error + Send + Sync + 'static>)
TransactionSummaryConstructionFailed(Box<dyn Error + Send + Sync + 'static>)
MalformedAssetInEventHandler
MalformedNoteStorage(NoteError)
MalformedNoteScript
MalformedRecipientData(Vec<Felt>)
MissingNote(usize)
PublicNoteMissingDetails(NoteMetadata, Word)
NoteAttachmentNoneIsNotEmpty
NoteAttachmentArrayMismatch
TooFewElementsForNoteStorage
UnknownAccountProcedure(Word)
UnknownCodeCommitment(Word)
AccountStorageSlotsNumMissing(u32)
NonceCanOnlyIncrementOnce
FailedToConvertFeeAsset(AssetError)
GetForeignAccountInputs
GetVaultAssetWitness
GetStorageMapWitness
InsufficientFee
This variant signals that a signature over the contained commitments is required, but missing.
Other
A generic error returned when the transaction kernel did not behave as expected.
Implementations
Sourceimpl TransactionKernelError
impl TransactionKernelError
Sourcepub fn other(message: impl Into<String>) -> Self
pub fn other(message: impl Into<String>) -> Self
Creates a custom error using the TransactionKernelError::Other variant from an error
message.
Sourcepub fn other_with_source(
message: impl Into<String>,
source: impl Error + Send + Sync + 'static,
) -> Self
pub fn other_with_source( message: impl Into<String>, source: impl Error + Send + Sync + 'static, ) -> Self
Creates a custom error using the TransactionKernelError::Other variant from an error
message and a source error.