pub struct AccountProcedureIndexMap(/* private fields */);Expand description
A map of maps { acct_code_commitment |-> { proc_root |-> proc_index } } for all known procedures of account interfaces for all accounts expected to be invoked during transaction execution.
Implementations
Sourceimpl AccountProcedureIndexMap
impl AccountProcedureIndexMap
Sourcepub fn new<'code>(
account_codes: impl IntoIterator<Item = &'code AccountCode>,
) -> Result<Self, TransactionHostError>
pub fn new<'code>( account_codes: impl IntoIterator<Item = &'code AccountCode>, ) -> Result<Self, TransactionHostError>
Returns a new AccountProcedureIndexMap instantiated with account procedures from the
provided iterator of AccountCode.
Sourcepub fn insert_code(
&mut self,
code: &AccountCode,
) -> Result<(), TransactionHostError>
pub fn insert_code( &mut self, code: &AccountCode, ) -> Result<(), TransactionHostError>
Inserts the procedures from the provided AccountCode into the advice inputs, using
AccountCode::commitment as the key.
The resulting instance will map the account code commitment to a mapping of
proc_root |-> proc_index for any account that is expected to be involved in the
transaction, enabling fast procedure index lookups at runtime.
Sourcepub fn get_proc_index(
&self,
process: &ProcessState<'_>,
) -> Result<u8, TransactionKernelError>
pub fn get_proc_index( &self, process: &ProcessState<'_>, ) -> Result<u8, TransactionKernelError>
Returns index of the procedure whose root is currently at the top of the operand stack in the provided process.
Errors
Returns an error if the procedure at the top of the operand stack is not present in this map.