pub struct ScriptMastForestStore { /* private fields */ }Expand description
Stores the MAST forests for a set of scripts (both note scripts and transaction scripts).
A ScriptMastForestStore is meant to exclusively store MAST forests related to both transaction and input note scripts.
Implementations
Sourceimpl ScriptMastForestStore
impl ScriptMastForestStore
Sourcepub fn new(
tx_script: Option<&TransactionScript>,
note_scripts: impl Iterator<Item = impl AsRef<NoteScript>>,
) -> Self
pub fn new( tx_script: Option<&TransactionScript>, note_scripts: impl Iterator<Item = impl AsRef<NoteScript>>, ) -> Self
Creates a new ScriptMastForestStore.
Sourcepub fn advice_map(&self) -> &AdviceMap
pub fn advice_map(&self) -> &AdviceMap
Returns a reference to the advice data collected from all forests.