TransactionExecutor

Struct TransactionExecutor 

pub struct TransactionExecutor<'store, 'auth, STORE: 'store, AUTH: 'auth> { /* private fields */ }
The transaction executor is responsible for executing Miden blockchain transactions.

Transaction execution consists of the following steps:

The transaction executor uses dynamic dispatch with trait objects for the DataStore and TransactionAuthenticator, allowing it to be used with different backend implementations. At the moment of execution, the DataStore is expected to provide all required MAST nodes.

Implementations

Source

impl<'store, 'auth, STORE, AUTH> TransactionExecutor<'store, 'auth, STORE, AUTH>
where STORE: DataStore + 'store + Sync, AUTH: TransactionAuthenticator + 'auth + Sync,

pub fn new(data_store: &'store STORE) -> Self

Creates a new TransactionExecutor instance with the specified DataStore.

The created executor will not have the authenticator or source manager set, and tracing and debug mode will be turned off.

pub fn with_authenticator(self, authenticator: &'auth AUTH) -> Self

Adds the specified TransactionAuthenticator to the executor and returns the resulting executor.

This will overwrite any previously set authenticator.

pub fn with_source_manager( self, source_manager: Arc<dyn SourceManagerSync>, ) -> Self

Adds the specified source manager to the executor and returns the resulting executor.

The source_manager is used to map potential errors back to their source code. To get the most value out of it, use the same source manager as was used with the Assembler that assembled the Miden Assembly code that should be debugged, e.g. account components, note scripts or transaction scripts.

This will overwrite any previously set source manager.

pub fn with_options( self, exec_options: ExecutionOptions, ) -> Result<Self, TransactionExecutorError>

Sets the ExecutionOptions for the executor to the provided options and returns the resulting executor.

Errors

Returns an error if the specified cycle values (max_cycles and expected_cycles) in the ExecutionOptions are not within the range MIN_TX_EXECUTION_CYCLES and MAX_TX_EXECUTION_CYCLES.

pub fn with_debug_mode(self) -> Self

Puts the TransactionExecutor into debug mode and returns the resulting executor.

When transaction executor is in debug mode, all transaction-related code (note scripts, account code) will be compiled and executed in debug mode. This will ensure that all debug instructions present in the original source code are executed.

pub fn with_tracing(self) -> Self

Enables tracing for the created instance of TransactionExecutor and returns the resulting executor.

When tracing is enabled, the executor will receive tracing events as various stages of the transaction kernel complete. This enables collecting basic stats about how long different stages of transaction execution take.

pub async fn execute_transaction( &self, account_id: AccountId, block_ref: BlockNumber, notes: InputNotes<InputNote>, tx_args: TransactionArgs, ) -> Result<ExecutedTransaction, TransactionExecutorError>

Prepares and executes a transaction specified by the provided arguments and returns an ExecutedTransaction.

The method first fetches the data required to execute the transaction from the DataStore and compile the transaction into an executable program. In particular, it fetches the account identified by the account ID from the store as well as block_ref, the header of the reference block of the transaction and the set of headers from the blocks in which the provided notes were created. Then, it executes the transaction program and creates an ExecutedTransaction.

Errors:

Returns an error if:

  • If required data can not be fetched from the DataStore.
  • If the transaction arguments contain foreign account data not anchored in the reference block.
  • If any input notes were created in block numbers higher than the reference block.
pub async fn execute_tx_view_script( &self, account_id: AccountId, block_ref: BlockNumber, tx_script: TransactionScript, advice_inputs: AdviceInputs, ) -> Result<[Felt; 16], TransactionExecutorError>

Executes an arbitrary script against the given account and returns the stack state at the end of execution.

Errors:

Returns an error if:

  • If required data can not be fetched from the DataStore.
  • If the transaction host can not be created from the provided values.
  • If the execution of the provided program fails.