pub struct AccountProcedureIndexMap(/* private fields */);Expand description
A map of maps { acct_code_commitment |-> { proc_root |-> proc_index } } for all known procedures of account interfaces for all accounts expected to be invoked during transaction execution.
Implementations
Sourceimpl AccountProcedureIndexMap
impl AccountProcedureIndexMap
Sourcepub fn new(
account_code_commitments: impl IntoIterator<Item = Word>,
adv_provider: &AdviceInputs,
) -> Result<Self, TransactionHostError>
pub fn new( account_code_commitments: impl IntoIterator<Item = Word>, adv_provider: &AdviceInputs, ) -> Result<Self, TransactionHostError>
Returns a new AccountProcedureIndexMap instantiated with account procedures present in the provided advice provider.
Note: account_code_commitments iterator should include both native account code and
foreign account codes commitments
Sourcepub fn from_transaction_params(
tx_inputs: &TransactionInputs,
tx_args: &TransactionArgs,
tx_advice_inputs: &TransactionAdviceInputs,
) -> Result<Self, TransactionHostError>
pub fn from_transaction_params( tx_inputs: &TransactionInputs, tx_args: &TransactionArgs, tx_advice_inputs: &TransactionAdviceInputs, ) -> Result<Self, TransactionHostError>
Builds an AccountProcedureIndexMap for the specified transaction inputs and arguments.
The resulting instance will map all account code commmitments to a mapping of
proc_root |-> proc_index for any account that is expected to be involved in the
transaction, enabling easy procedure index lookups on runtime.
Sourcepub fn get_proc_index(
&self,
process: &ProcessState<'_>,
) -> Result<u8, TransactionKernelError>
pub fn get_proc_index( &self, process: &ProcessState<'_>, ) -> Result<u8, TransactionKernelError>
Returns index of the procedure whose root is currently at the top of the operand stack in the provided process.
Errors
Returns an error if the procedure at the top of the operand stack is not present in this map.