pub struct TransactionExecutor<'store, 'auth> { /* private fields */ }Expand description
The transaction executor is responsible for executing Miden blockchain transactions.
Transaction execution consists of the following steps:
- Fetch the data required to execute a transaction from the DataStore.
- Execute the transaction program and create an ExecutedTransaction.
The transaction executor uses dynamic dispatch with trait objects for the DataStore and TransactionAuthenticator, allowing it to be used with different backend implementations. At the moment of execution, the DataStore is expected to provide all required MAST nodes.
Implementations
Sourceimpl<'store, 'auth> TransactionExecutor<'store, 'auth>
impl<'store, 'auth> TransactionExecutor<'store, 'auth>
Sourcepub fn new(
data_store: &'store dyn DataStore,
authenticator: Option<&'auth dyn TransactionAuthenticator>,
) -> Self
pub fn new( data_store: &'store dyn DataStore, authenticator: Option<&'auth dyn TransactionAuthenticator>, ) -> Self
Creates a new TransactionExecutor instance with the specified DataStore and TransactionAuthenticator.
Sourcepub fn with_options(
data_store: &'store dyn DataStore,
authenticator: Option<&'auth dyn TransactionAuthenticator>,
exec_options: ExecutionOptions,
) -> Result<Self, TransactionExecutorError>
pub fn with_options( data_store: &'store dyn DataStore, authenticator: Option<&'auth dyn TransactionAuthenticator>, exec_options: ExecutionOptions, ) -> Result<Self, TransactionExecutorError>
Creates a new TransactionExecutor instance with the specified DataStore, TransactionAuthenticator and ExecutionOptions.
The specified cycle values (max_cycles and expected_cycles) in the ExecutionOptions
must be within the range MIN_TX_EXECUTION_CYCLES and MAX_TX_EXECUTION_CYCLES.
Sourcepub fn with_debug_mode(self) -> Self
pub fn with_debug_mode(self) -> Self
Puts the TransactionExecutor into debug mode.
When transaction executor is in debug mode, all transaction-related code (note scripts, account code) will be compiled and executed in debug mode. This will ensure that all debug instructions present in the original source code are executed.
Sourcepub fn with_tracing(self) -> Self
pub fn with_tracing(self) -> Self
Enables tracing for the created instance of TransactionExecutor.
When tracing is enabled, the executor will receive tracing events as various stages of the transaction kernel complete. This enables collecting basic stats about how long different stages of transaction execution take.
Sourcepub fn execute_transaction(
&self,
account_id: AccountId,
block_ref: BlockNumber,
notes: InputNotes<InputNote>,
tx_args: TransactionArgs,
source_manager: Arc<dyn SourceManager>,
) -> Result<ExecutedTransaction, TransactionExecutorError>
pub fn execute_transaction( &self, account_id: AccountId, block_ref: BlockNumber, notes: InputNotes<InputNote>, tx_args: TransactionArgs, source_manager: Arc<dyn SourceManager>, ) -> Result<ExecutedTransaction, TransactionExecutorError>
Prepares and executes a transaction specified by the provided arguments and returns an
ExecutedTransaction.
The method first fetches the data required to execute the transaction from the DataStore
and compile the transaction into an executable program. In particular, it fetches the
account identified by the account ID from the store as well as block_ref, the header of
the reference block of the transaction and the set of headers from the blocks in which the
provided notes were created. Then, it executes the transaction program and creates an
ExecutedTransaction.
The source_manager is used to map potential errors back to their source code. To get the
most value out of it, use the source manager from the
Assembler that assembled the Miden Assembly code
that should be debugged, e.g. account components, note scripts or transaction scripts. If
no error-to-source mapping is desired, a default source manager can be passed, e.g.
DefaultSourceManager::default.
Errors:
Returns an error if:
- If required data can not be fetched from the
DataStore. - If the transaction arguments contain foreign account data not anchored in the reference block.
- If any input notes were created in block numbers higher than the reference block.
Sourcepub fn execute_tx_view_script(
&self,
account_id: AccountId,
block_ref: BlockNumber,
tx_script: TransactionScript,
advice_inputs: AdviceInputs,
foreign_account_inputs: Vec<AccountInputs>,
source_manager: Arc<dyn SourceManager>,
) -> Result<[Felt; 16], TransactionExecutorError>
pub fn execute_tx_view_script( &self, account_id: AccountId, block_ref: BlockNumber, tx_script: TransactionScript, advice_inputs: AdviceInputs, foreign_account_inputs: Vec<AccountInputs>, source_manager: Arc<dyn SourceManager>, ) -> Result<[Felt; 16], TransactionExecutorError>
Executes an arbitrary script against the given account and returns the stack state at the end of execution.
The source_manager is used to map potential errors back to their source code. To get the
most value out of it, use the source manager from the
Assembler that assembled the Miden Assembly code
that should be debugged, e.g. account components, note scripts or transaction scripts. If
no error-to-source mapping is desired, a default source manager can be passed, e.g.
DefaultSourceManager::default.
Errors:
Returns an error if:
- If required data can not be fetched from the DataStore.
- If the transaction host can not be created from the provided values.
- If the execution of the provided program fails.